@@ -1,3 +1,4 @@
+import json
 from typing import Annotated, Optional
 
 from rich import print
@@ -8,11 +9,13 @@ from typer import Argument, Typer
 from alga import client
 
 
-app = Typer(no_args_is_help=True)
+app = Typer(no_args_is_help=True, help="Apps installed on the TV")
 
 
 @app.command()
 def current() -> None:
+    """Get the current app"""
+
     response = client.request(
         "ssap://com.webos.applicationManager/getForegroundAppInfo"
     )
@@ -21,19 +24,28 @@ def current() -> None:
 
 @app.command()
 def close(app_id: Annotated[str, Argument()]) -> None:
-    client.request("ssap://system.launcher/close")
+    """Close the provided app"""
+
+    client.request("ssap://system.launcher/close", {"id": app_id})
 
 
 @app.command()
 def launch(
     app_id: Annotated[str, Argument()],
-    content: Annotated[Optional[str], Argument()] = None,
+    data: Annotated[Optional[str], Argument()] = None,
 ) -> None:
-    client.request("ssap://system.launcher/launch", {"id": app_id})
+    """Launch an app"""
+
+    payload = {"id": app_id}
+    if data:
+        payload.update(json.loads(data))
+    client.request("ssap://system.launcher/launch", payload)
 
 
 @app.command()
 def list() -> None:
+    """List installed apps"""
+
     response = client.request("ssap://com.webos.applicationManager/listApps")
 
     table = Table()
@@ -41,8 +53,8 @@ def list() -> None:
     table.add_column("ID")
 
     all_apps = []
-    for a in response["apps"]:
-        all_apps.append([a["title"], a["id"]])
+    for app in response["apps"]:
+        all_apps.append([app["title"], app["id"]])
 
     for row in sorted(all_apps):
         table.add_row(*row)
@@ -53,6 +65,8 @@ def list() -> None:
 
 @app.command()
 def info(app_id: str) -> None:
+    """Show info about specific app"""
+
     response = client.request(
         "ssap://com.webos.applicationManager/getAppInfo", {"id": app_id}
     )
